==> haskell-hsopenssl-0.11.4.15-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hsopenssl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: HsOpenSSL
version: 0.11.4.15
id: HsOpenSSL-0.11.4.15-HtXpkfzA1nODGmxt96PiAW
key: HsOpenSSL-0.11.4.15-HtXpkfzA1nODGmxt96PiAW
license: LicenseRef-PublicDomain
maintainer: Vladimir Shabanov <dev@vshabanov.com>
author: Adam Langley, Mikhail Vorozhtsov, PHO, Taru Karttunen
stability: stable
homepage: https://github.com/vshabanov/HsOpenSSL
synopsis: Partial OpenSSL binding for Haskell
description:
    .
    HsOpenSSL is an OpenSSL binding for Haskell. It can generate RSA
    and DSA keys, read and write PEM files, generate message digests,
    sign and verify messages, encrypt and decrypt messages. It has
    also some capabilities of creating SSL clients and servers.
    .
    This package is in production use by a number of Haskell based
    systems and stable. You may also be interested in the @tls@ package,
    <http://hackage.haskell.org/package/tls>, which is a pure Haskell
    implementation of SSL.
    .
category: Cryptography
abi: 4c7f3509e98ae95e2210162eb6b5ae79
exposed: True
exposed-modules:
    OpenSSL OpenSSL.BN OpenSSL.Cipher OpenSSL.DER OpenSSL.DH
    OpenSSL.DSA OpenSSL.EVP.Base64 OpenSSL.EVP.Cipher
    OpenSSL.EVP.Digest OpenSSL.EVP.Internal OpenSSL.EVP.Open
    OpenSSL.EVP.PKey OpenSSL.EVP.Seal OpenSSL.EVP.Sign
    OpenSSL.EVP.Verify OpenSSL.PEM OpenSSL.PKCS7 OpenSSL.RSA
    OpenSSL.Random OpenSSL.Session OpenSSL.X509 OpenSSL.X509.Request
    OpenSSL.X509.Revocation OpenSSL.X509.Store
hidden-modules: OpenSSL.ASN1 OpenSSL.BIO OpenSSL.ERR
                OpenSSL.Objects OpenSSL.SSL.Option OpenSSL.Stack OpenSSL.Utils
                OpenSSL.X509.Name OpenSSL.DH.Internal
import-dirs: /usr/lib/ghc-8.6.2/site-local/HsOpenSSL-0.11.4.15
library-dirs: /usr/lib/ghc-8.6.2/site-local/HsOpenSSL-0.11.4.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/HsOpenSSL-0.11.4.15
hs-libraries: HSHsOpenSSL-0.11.4.15-HtXpkfzA1nODGmxt96PiAW
extra-libraries:
    ssl crypto
includes:
    openssl/asn1.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    network-2.7.0.2-2fEEs0vTvHq3lWAStilHpJ time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-hsopenssl/html/HsOpenSSL.haddock
haddock-html: /usr/share/doc/haskell-hsopenssl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsopenssl-0.11.4.15-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hsopenssl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: HsOpenSSL
version: 0.11.4.15
id: HsOpenSSL-0.11.4.15-CQ2J7qnzJMI5whbcUUtFqY
key: HsOpenSSL-0.11.4.15-CQ2J7qnzJMI5whbcUUtFqY
license: LicenseRef-PublicDomain
maintainer: Vladimir Shabanov <dev@vshabanov.com>
author: Adam Langley, Mikhail Vorozhtsov, PHO, Taru Karttunen
stability: stable
homepage: https://github.com/vshabanov/HsOpenSSL
synopsis: Partial OpenSSL binding for Haskell
description:
    .
    HsOpenSSL is an OpenSSL binding for Haskell. It can generate RSA
    and DSA keys, read and write PEM files, generate message digests,
    sign and verify messages, encrypt and decrypt messages. It has
    also some capabilities of creating SSL clients and servers.
    .
    This package is in production use by a number of Haskell based
    systems and stable. You may also be interested in the @tls@ package,
    <http://hackage.haskell.org/package/tls>, which is a pure Haskell
    implementation of SSL.
    .
category: Cryptography
abi: db9285dbeb4efe07fd145b200e73068f
exposed: True
exposed-modules:
    OpenSSL OpenSSL.BN OpenSSL.Cipher OpenSSL.DER OpenSSL.DH
    OpenSSL.DSA OpenSSL.EVP.Base64 OpenSSL.EVP.Cipher
    OpenSSL.EVP.Digest OpenSSL.EVP.Internal OpenSSL.EVP.Open
    OpenSSL.EVP.PKey OpenSSL.EVP.Seal OpenSSL.EVP.Sign
    OpenSSL.EVP.Verify OpenSSL.PEM OpenSSL.PKCS7 OpenSSL.RSA
    OpenSSL.Random OpenSSL.Session OpenSSL.X509 OpenSSL.X509.Request
    OpenSSL.X509.Revocation OpenSSL.X509.Store
hidden-modules: OpenSSL.ASN1 OpenSSL.BIO OpenSSL.ERR
                OpenSSL.Objects OpenSSL.SSL.Option OpenSSL.Stack OpenSSL.Utils
                OpenSSL.X509.Name OpenSSL.DH.Internal
import-dirs: /usr/lib/ghc-8.6.3/site-local/HsOpenSSL-0.11.4.15
library-dirs: /usr/lib/ghc-8.6.3/site-local/HsOpenSSL-0.11.4.15
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/HsOpenSSL-0.11.4.15
hs-libraries: HSHsOpenSSL-0.11.4.15-CQ2J7qnzJMI5whbcUUtFqY
extra-libraries:
    ssl crypto
includes:
    openssl/asn1.h
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    network-2.7.0.2-l7ToO0nOP7DBjiP2hy2PR time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-hsopenssl/html/HsOpenSSL.haddock
haddock-html: /usr/share/doc/haskell-hsopenssl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
